@@ -6,6 +6,8 @@
 
 latlongLandmarks <- function(path) {
   lndmrks <- landmarkData()
+  variable.chk <- grepl("lon", names(lndmrks)) | grepl("lat", names(lndmrks))
+  if (any(variable.chk)) lndmrks <- lndmrks[, !variable.chk]
   dat <- lndmrks[-grep("Square", lndmrks$name), ]
   dat <- dat[dat$name != "The Pantheon", ]
   k <- nrow(dat)
@@ -86,10 +88,8 @@ latlongLandmarks <- function(path) {
   out.geo <- lapply(seq_len(nrow(sq)), function(i) {
     sel1 <- signif(rd.nom$x1) %in% signif(sq[i, ]$x) &
             signif(rd.nom$y1) %in% signif(sq[i, ]$y)
-
     sel2 <- signif(rd.nom$x2) %in% signif(sq[i, ]$x) &
             signif(rd.nom$y2) %in% signif(sq[i, ]$y)
-
     nodes.select <- rd.geo[sel1 | sel2, ]
 
     ones <- vapply(seq_len(nrow(nodes.select)), function(i) {
@@ -127,10 +127,8 @@ latlongLandmarks <- function(path) {
 
   sel1 <- signif(rd.nom$x1) %in% signif(pantheon$x) &
           signif(rd.nom$y1) %in% signif(pantheon$y)
-
   sel2 <- signif(rd.nom$x2) %in% signif(pantheon$x) &
           signif(rd.nom$y2) %in% signif(pantheon$y)
-
   nodes.select <- rd.geo[sel1 | sel2, ]
 
   if (sum(sel1) > sum(sel2)) sel <- one
@@ -172,6 +170,8 @@ landmarksPDF <- function(path, orthogonal = FALSE, pch = 15, cex = 0.2) {
   pre <- paste0(file.nm, ".")
   post <- "pdf"
   dat <- landmarkData()
+  variable.chk <- grepl("lon", names(dat)) | grepl("lat", names(dat))
+  if (any(variable.chk)) dat <- dat[, !variable.chk]
 
   # Exclude Squares from georeferencing
   dat <- dat[-grep("Square", dat$name), ]
